@@ -328,7 +328,7 @@ avec ce programme&#x202f;; si ce n&apos;est pas le cas, consultez &lt;http://www
     <message>
         <location filename="../mainwindow.ui" line="249"/>
         <source>Alt+Return</source>
-        <translation>Alt+Entrée</translation>
+        <translation>Alt+Return</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="258"/>
